import random
import string

def generate(length=8, use_uppercase = True, use_digits = True, use_symbols = True):

    if length < 4:
        raise ValueError("Password length must be at least 4")

    characters = string.ascii_lowercase
    if use_uppercase:
        characters += string.ascii_uppercase
    if use_digits:
        characters += string.digits
    if use_symbols:
        characters += "!@#$%^&*()-_=+[]{}|;:,.<>?/~`"

    return ''.join(random.choice(characters) for _ in range(length))


import math
import string

def entropy(password):
    charset = 0
    if any(c in string.ascii_lowercase for c in password):
        charset += 26
    if any(c in string.ascii_uppercase for c in password):
        charset += 26
    if any(c in string.digits for c in password):
        charset += 10
    if any(c in "!@#$%^&*()-_=+[]{}|;:,.<>?/~`" for c in password):
        charset += 32

    entropy = len(password) * math.log2(charset) if charset > 0 else 0
    return round(entropy, 2)

def strength(password):
    ent = entropy(password)
    if ent < 28:
        return "Very Weak"
    elif ent < 40:
        return "Weak"
    elif ent < 60:
        return "Moderate"
    elif ent < 80:
        return "Strong"
    else:
        return "Very Strong"




from setuptools import setup, find_packages

setup(
    name='pylockgen',
    version='1.3.1',
    author='Hadi Reza',
    author_email='hadiraza.9002@gmail.com',
    description='Secure password generator and strength checker',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/unknownmeovo/pylockgen",
    project_urls={
        "Bug Tracker": "https://github.com/unknownmeovo/pylockgen/issues",
    },
    license='MIT',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        "Topic :: Security",
	"Topic :: Utilities"
    ],
    python_requires='>=3.6',
)
